//
//  View.m
//  Pig
//
//  Created by Mark Meretzky on 10/28/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import "View.h"

@implementation View

- (id) initWithFrame: (CGRect) frame
{
	self = [super initWithFrame:frame];
	if (self) {
		// Initialization code
		self.backgroundColor = [UIColor whiteColor];
		UIFont *font = [UIFont systemFontOfSize: 24];
		NSDictionary *attributes =
			[NSDictionary dictionaryWithObject: font forKey: NSFontAttributeName];
		CGFloat height = [@"A" sizeWithAttributes: attributes].height;

		CGRect b = self.bounds;
		CGFloat margin = b.size.width / 20;

		CGRect f = CGRectMake(
			b.origin.x + margin,
			b.origin.y + margin,
			b.size.width - 2 * margin,
			height
		);

		textField = [[UITextField alloc] initWithFrame: f];
		textField.borderStyle = UITextBorderStyleLine;	//default
		textField.backgroundColor = [UIColor yellowColor];
		textField.textColor = [UIColor blackColor];

		textField.clearButtonMode = UITextFieldViewModeAlways;
		textField.keyboardType = UIKeyboardTypeDefault;
		textField.returnKeyType = UIReturnKeyDone;

		textField.font = font;
		textField.placeholder = @"<type a word>";
		textField.textAlignment = NSTextAlignmentLeft;	//default
		textField.autocapitalizationType = UITextAutocapitalizationTypeNone;
		textField.autocorrectionType = UITextAutocorrectionTypeNo;
		textField.secureTextEntry = NO;	//for secret passwords

		textField.delegate = self;

		f = CGRectMake(
			b.origin.x + margin,
			b.origin.y + textField.bounds.size.height + 2 * margin,
			b.size.width - 2 * margin,
			height
		);

		label = [[UILabel alloc] initWithFrame: f];
		label.backgroundColor = [UIColor orangeColor];
		label.font = font;
		label.hidden = YES;	//until user presses Done button

		[self addSubview: textField];
		[self addSubview: label];
	}
	return self;
}

#pragma mark -
#pragma mark methods of UITextFieldDelegate protocol

//Called when user taps the text field.  He or she is about to
//type a new word, so hide the Pig Latin translation of the old
//word.

- (void) textFieldDidBeginEditing: (UITextField *) textField
{
	label.hidden = YES;
}

//Called when return key is pressed.
//Decide if the app should accept this input and hide the keyboard.

- (BOOL) textFieldShouldReturn: (UITextField *) tf {
	if ([tf.text isEqualToString: @""]) {
		textField.placeholder = @"<type a non-empty word>";
	} else {
		[tf resignFirstResponder];	//Hide keyboard.
	}
	return YES;	//The text field should do its default behavior.
}

//Called when keyboard is hidden.
//Process the text that was input.

- (void) textFieldDidEndEditing: (UITextField *) tf {
	if ([textField.text isEqualToString: @""]) {
		label.text = @"";
	} else {
		NSString *lowercase = [textField.text lowercaseString];
		
		label.text = [NSString stringWithFormat: @"%@%@ay",
			[lowercase substringFromIndex: 1],	//all characters except the first
			[lowercase substringToIndex: 1]		//the first character
		];
		label.hidden = NO;
	}
}

/*
Height of keyboard on 4-inch diagonal portrait iPhone is 216 pairs of pixels.
Since the Y axis points up, we have to specify the coordinates of the
lower left corner of the rectangles.
*/

- (void) drawRect: (CGRect) rect
{
	// Drawing code
	CGSize size = self.bounds.size;
	CGFloat width = size.width / 2;
	CGFloat height = 216;
	CGContextRef c = UIGraphicsGetCurrentContext();

	CGContextBeginPath(c);
	//origin at center of bottom edge
	CGContextTranslateCTM(c, size.width / 2, size.height);
	CGContextScaleCTM(c, 1, -1);

	CGContextAddRect(c, CGRectMake(-width, 0, width, height));
	CGContextAddRect(c, CGRectMake(0,      0, width, height + 1));

	CGContextSetRGBFillColor(c, 0, 0, 1, 1);
	CGContextFillPath(c);
}

@end
